@@ -65,8 +65,6 @@ class Experimento:
                                 'no es un archivo separado por comas o puntos y comas.')
         print("Obteniendo datos de csv...")
         df = dataframe_a_recortar
-        print(df)
-        print(df.values[0])
         try:
             inicio_datos = df.index[df[0] == 'Sample no.'].tolist()
             print("Los datos empiezan en la fila", inicio_datos)
@@ -83,7 +81,6 @@ class Experimento:
         except:
             raise Exception('El archivo ', nombre_recortado.stem, 'no es compatible con motus.')
 
-        print(self.datos)
         longitud_datos = len(self.datos)
         try:
             arreglo_samples = pd.to_numeric(self.datos['Sample no.'].tail(longitud_datos))
@@ -99,9 +96,9 @@ class Experimento:
 
         print("--------------------------------------")
 
-        print(arreglo_tiempo)
-        print(arreglo_posicion_x)
-        print(arreglo_posicion_y)
+        print("Tiempo:", arreglo_tiempo)
+        print("Pos. eje x", arreglo_posicion_x)
+        print("Pos eje y", arreglo_posicion_y)
 
         if puntos_importantes is None:
 
@@ -131,10 +128,10 @@ class Experimento:
         self.indice_region_objeto_3 = None
         self.indice_region_objeto_4 = None
 
-        print(self.objeto_relevante_1)
-        print(self.objeto_relevante_2)
-        print(self.objeto_relevante_3)
-        print(self.objeto_relevante_4)
+        print("Objeto relevante 1:", self.objeto_relevante_1)
+        print("Objeto relevante 2:", self.objeto_relevante_2)
+        print("Objeto relevante 3:", self.objeto_relevante_3)
+        print("Objeto relevante 4:", self.objeto_relevante_4)
 
         self.posiciones_x = arreglo_posicion_x
         self.posiciones_y = arreglo_posicion_y
@@ -163,11 +160,9 @@ class Experimento:
                               "ajustando el valor de los intervalos entre frames a un valor medio, con base en el "
                               "siguiente cálculo: Intervalo = (Tiempo final - tiempo inicial)/total de registros")
         else:
-            print("Llego aquí")
+            print("Se empieza la generación de tiempos regulares: ")
             self.genera_tiempos_regulares()
 
-        print("2")
-
         self.distancia_total_recorrida = 0
 
         self.dist_objeto_1 = None
@@ -246,7 +241,7 @@ class Experimento:
         arreglo_tiempo = self.tiempo
         valor = True
         nuevo_valor = 0
-        print(arreglo_tiempo)
+        print("Tiempo: ", arreglo_tiempo)
         for i in range(len(arreglo_tiempo)):
             print("Nuevo valor:", nuevo_valor)
             print("Valor a comparar:", arreglo_tiempo[i])
@@ -263,8 +258,8 @@ class Experimento:
         tiempo_inicial = tiempo_a_utilizar[0]
         tiempo_final = tiempo_a_utilizar[-1]
         nuevos_tiempos = pd.Series(np.linspace(tiempo_inicial, tiempo_final, tiempo_total), name='Time')
-        print(self.tiempo)
-        print(nuevos_tiempos)
+        print("Tiempo original:", self.tiempo)
+        print("Tiempos nuevos:", nuevos_tiempos)
         self.tiempo = nuevos_tiempos
 
     def calcula_distancias(self):
@@ -371,7 +366,7 @@ class Experimento:
                                            categoria="velocidad",
                                            serie=self.serie_velocidad)
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
-                                       categoria="velocidad",
+                                       categoria="histograma_velocidad",
                                        datos=self.histogramas["velocidad"])
 
         longitud_velocidad = len(lista_velocidad)
@@ -531,6 +526,8 @@ class Experimento:
                         self.matriz_recurrencia_combinada[i][j] = 4
 
     def calcula_matrices_regiones_preferidas(self):
+
+        print("Se inicia el procesamiento de las matrices con regiones preferidas")
         matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
 
         self.matriz_cuadriculada_solo_regiones_preferidas = \
@@ -542,10 +539,11 @@ class Experimento:
                                        categoria="visitas_regiones_preferidas",
                                        datos=self.matriz_cuadriculada_solo_regiones_preferidas.flatten())
 
-        self.matriz_cuadriculada_solo_regiones_no_preferidas = \
-            np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
         self.matriz_cuadriculada_solo_regiones_no_preferidas = \
             rp.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_no_preferidas)
+        self.matriz_cuadriculada_solo_regiones_no_preferidas = \
+            np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
+
 
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="visitas_regiones_no_preferidas",
