@@ -3,9 +3,15 @@ import scipy.stats as st
 
 
 def agrega_categoria_entropia(diccionario_entropia, categoria, datos):
+    print("Agrego categoria de entropia: ")
+    print("--------------------------------------------------------------")
+    print("Diccionario:", diccionario_entropia)
+    print("Categora", categoria)
+    print("Datos:", datos)
     nuevos_datos = np.array(datos)
     if categoria not in diccionario_entropia:
         diccionario_entropia[categoria] = st.entropy(nuevos_datos)
+    print("Nuevo diccionario: ", diccionario_entropia)
 
 
 def modificar_matriz_para_evitar_divergencia_infinita(datos):
