@@ -28,7 +28,9 @@ def obtener_complemento_de_sublista(lista, sublista):
 
 
 def obtener_submatriz_indices_dados(matriz, lista_indices):
+    print("inicio proceso para obtener valores en subindices dados para la matriz: ", matriz)
     copia_matriz_plana = matriz.copy().flatten()
+    print("Submatriz plana: ", copia_matriz_plana)
     matriz_posiciones_interes = copia_matriz_plana[lista_indices]
 
     arreglo_valores_resultantes = np.zeros(len(copia_matriz_plana))
@@ -39,5 +41,7 @@ def obtener_submatriz_indices_dados(matriz, lista_indices):
 
     matriz_resultante = np.reshape(arreglo_valores_resultantes, (total_filas, total_columnas))
 
+    print("Matriz resultante: ")
+
     return matriz_resultante
 
